From f36226fc498dc821344986830ce2ebae8951408f Mon Sep 17 00:00:00 2001
From: "fu.lin" <fulin10@huawei.com>
Date: Mon, 29 Nov 2021 19:50:39 +0800
Subject: [PATCH 52/54] dump: ignore children exit to accelerate speed

don't care the tracee exit status to accelerate dump speed. Just ignore
SIGCHLD signal.

Theory:
- criu don't care about `wait4()` status for tracee: in original process,
  criu just complains if the status of `wait4()` is abnormal, no action
  will be processed.
- the tracee will be adopted by the tracer's parent if the tracer exited
  is early than tracee, no zombie tracee will be left.

Signed-off-by: fu.lin <fulin10@huawei.com>
---
 criu/seize.c | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/criu/seize.c b/criu/seize.c
index 056454d..cad6919 100644
--- a/criu/seize.c
+++ b/criu/seize.c
@@ -761,7 +761,9 @@ void pstree_switch_state(struct pstree_item *root_item, int st)
 	for_each_pstree_item(item)
 		unseize_task_and_threads(item, st);
 
-	if (st == TASK_DEAD)
+	if (st == TASK_DEAD && opts.parallel)
+		signal(SIGCHLD, SIG_IGN); /* ignore children exit */
+	else if (st == TASK_DEAD)
 		pstree_wait(root_item);
 }
 
-- 
2.33.1

